@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO application schema information
-#' @return Object of \code{\link{R6Class}} for modelling an ISO ApplicationSchemaInformation
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO ApplicationSchemaInformation
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_ApplicationSchemaInformation}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mas/1.0/mas/#element_MD_ApplicationSchemaInformation}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,7 +18,10 @@ ISOApplicationSchemaInformation <- R6Class("ISOApplicationSchemaInformation",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MD_ApplicationSchemaInformation",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MAS"
+     )
    ),
    public = list(
      
@@ -28,15 +33,15 @@ ISOApplicationSchemaInformation <- R6Class("ISOApplicationSchemaInformation",
      constraintLanguage = NULL,
      #'@field schemaAscii schemaAscii [0..1]
      schemaAscii = NULL,
-     #'@field graphicsFile graphicsFile [0..1] 
+     #'@field graphicsFile graphicsFile [0..1]: ISOOnlineResource
      graphicsFile = NULL,
-     #'@field softwareDevelopmentFile softwareDevelopmentFile [0..1]
+     #'@field softwareDevelopmentFile softwareDevelopmentFile [0..1]: ISOOnlineResource
      softwareDevelopmentFile = NULL,
      #'@field softwareDevelopmentFileFormat softwareDevelopmentFileFormat [0..1]
      softwareDevelopmentFileFormat = NULL,
     
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -86,4 +91,4 @@ ISOApplicationSchemaInformation <- R6Class("ISOApplicationSchemaInformation",
        self$softwareDevelopmentFileFormat <- format
      }
    )                        
-)
\ No newline at end of file
+)
