@@ -4,14 +4,16 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO binary
-#' @return Object of \code{\link{R6Class}} for modelling an ISO UnlimitedInteger
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO UnlimitedInteger
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   bin <- ISOBinary$new(value = "http://someuri")
 #'  
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gco/1.0/gco/#element_Binary}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gco/1.0/gco/#element_Binary}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -19,7 +21,10 @@ ISOBinary <- R6Class("ISOBinary",
  inherit = ISOAbstractObject,
  private = list(
    xmlElement = "Binary",
-   xmlNamespacePrefix = "GCO"
+   xmlNamespacePrefix = list(
+     "19139" = "GCO",
+     "19115-3" = "GCO"
+   )
  ),
  public = list(
    #'@field value value
@@ -28,11 +33,11 @@ ISOBinary <- R6Class("ISOBinary",
    attrs = list(),
    
    #'@description Initializes object
-   #'@param xml object of class \link{XMLInternalNode-class}
+   #'@param xml object of class \link[XML]{XMLInternalNode-class}
    #'@param value value
    initialize = function(xml = NULL, value){
      super$initialize(xml = xml)
      if(is.null(xml)) self$value <- value
    }
  )                        
-)
\ No newline at end of file
+)
