@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO extent
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Extent
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Extent
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_EX_Extent}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gex/1.0/gex/#element_EX_Extent}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,7 +18,10 @@ ISOExtent <- R6Class("ISOExtent",
    inherit = ISOAbstractObject,
    private = list(
       xmlElement = "EX_Extent",
-      xmlNamespacePrefix = "GMD"
+      xmlNamespacePrefix = list(
+        "19139" = "GMD",
+        "19115-3" = "GEX"
+      )
    ),
    public = list(
      #'@field geographicElement geographicElement [0..*]: ISOGeographicExtent
@@ -27,7 +32,7 @@ ISOExtent <- R6Class("ISOExtent",
      verticalElement = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -100,4 +105,4 @@ ISOExtent <- R6Class("ISOExtent",
        return(self$delListElement("verticalElement", element))
      }
    )                        
-)
\ No newline at end of file
+)
