@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO georectified
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Georectified
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Georectified
+#' @format \code{\link[R6]{R6Class}} object.
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Georectified}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MD_Georectified}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,7 +18,10 @@ ISOGeorectified <- R6Class("ISOGeorectified",
    inherit = ISOGridSpatialRepresentation,
    private = list(
      xmlElement = "MD_Georectified",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MSR"
+     )
    ),
    public = list(
      
@@ -36,7 +41,7 @@ ISOGeorectified <- R6Class("ISOGeorectified",
      transformationDimensionMapping = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -120,4 +125,4 @@ ISOGeorectified <- R6Class("ISOGeorectified",
      }
      
    )                        
-)
\ No newline at end of file
+)
