@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery image description
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery image description
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery image description
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create image description
@@ -60,7 +60,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_ImageDescription}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrc/1.0/mrc/#element_MI_ImageDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -68,14 +70,17 @@ ISOImageryImageDescription <- R6Class("ISOImageryImageDescription",
    inherit = ISOImageDescription,
    private = list(
      xmlElement = "MI_ImageDescription",
-     xmlNamespacePrefix = "GMI"
+     xmlNamespacePrefix = list(
+       "19139" = "GMI",
+       "19115-3" = "MRC"
+     )
    ),
    public = list(
      #'@field rangeElementDescription rangeElementDescription [0..*] : ISOImageryRangeElementDescription
      rangeElementDescription = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -100,4 +105,4 @@ ISOImageryImageDescription <- R6Class("ISOImageryImageDescription",
        return(self$delListElement("rangeElementDescription", description))
      }
    )                        
-)
\ No newline at end of file
+)
