@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery PlatformPass
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery PlatformPass
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery PlatformPass
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    md <- ISOImageryPlatformPass$new()
@@ -22,7 +22,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_PlatformPass}
+#'   
+#'   - 19115-3 \url{https://schemas.isotc211.org/19115/-3/mac/2.0/mac/#element_MI_PlatformPass}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -30,7 +32,10 @@ ISOImageryPlatformPass <- R6Class("ISOImageryPlatformPass",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MI_PlatformPass",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MAC"
+    )
   ),
   public = list(
     
@@ -42,7 +47,7 @@ ISOImageryPlatformPass <- R6Class("ISOImageryPlatformPass",
     relatedEvent = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -91,4 +96,4 @@ ISOImageryPlatformPass <- R6Class("ISOImageryPlatformPass",
     }
     
   )                        
-)
\ No newline at end of file
+)
