@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery range element description
-#' @return Object of \code{\link{R6Class}} for modelling an ISOImageryRangeElementDescription
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISOImageryRangeElementDescription
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create object
@@ -17,7 +17,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_RangeElementDescription}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrc/1.0/mrc/#element_MI_RangeElementDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -25,7 +27,10 @@ ISOImageryRangeElementDescription <- R6Class("ISOImageryRangeElementDescription"
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MI_RangeElementDescription",
-     xmlNamespacePrefix = "GMI"
+     xmlNamespacePrefix = list(
+       "19139" = "GMI",
+       "19115-3" = "MRC"
+     )
    ),
    public = list(
      
@@ -37,7 +42,7 @@ ISOImageryRangeElementDescription <- R6Class("ISOImageryRangeElementDescription"
      rangeElement = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -90,4 +95,4 @@ ISOImageryRangeElementDescription <- R6Class("ISOImageryRangeElementDescription"
        return(self$delListElement("rangeElement", record))
      }
    )                        
-)
\ No newline at end of file
+)
