@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO language
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Language
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Language
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   #possible values
@@ -15,7 +15,9 @@
 #'   eng <- ISOLanguage$new(value = "eng")
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_LanguageCode}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_LanguageCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,12 +25,15 @@ ISOLanguage <- R6Class("ISOLanguage",
   inherit = ISOCodeListValue,
   private = list(
     xmlElement = "LanguageCode",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "LAN"
+    )
   ),
   public = list(
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}  
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}  
     #'@param value value
     #'@param description description
     initialize = function(xml = NULL, value, description = NULL){
@@ -40,4 +45,4 @@ ISOLanguage <- R6Class("ISOLanguage",
 
 ISOLanguage$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISOLanguage, labels))
-}
\ No newline at end of file
+}
