@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO process step
-#' @return Object of \code{\link{R6Class}} for modelling an ISO ProcessStep
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO ProcessStep
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   ps <- ISOProcessStep$new()
@@ -18,7 +18,9 @@
 #'   xml <- ps$encode()
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_LI_ProcessStep}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrl/2.0/mrl/#element_LI_ProcessStep}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -26,7 +28,10 @@ ISOProcessStep <- R6Class("ISOProcessStep",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "LI_ProcessStep",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MRL"
+     )
    ),
    public = list(
   
@@ -42,7 +47,7 @@ ISOProcessStep <- R6Class("ISOProcessStep",
      source = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -117,4 +122,4 @@ ISOProcessStep <- R6Class("ISOProcessStep",
      }
      
    )                        
-)
\ No newline at end of file
+)
