@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO spatialtemporal extent
-#' @return Object of \code{\link{R6Class}} for modelling an ISO SpatialTemporalExtent
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO SpatialTemporalExtent
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   #create object
@@ -20,7 +20,9 @@
 #'   xml <- md$encode()
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_EX_SpatialTemporalExtent}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gex/1.0/gex/#element_EX_SpatialTemporalExtent}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -28,14 +30,17 @@ ISOSpatialTemporalExtent <- R6Class("ISOSpatialTemporalExtent",
    inherit = ISOTemporalExtent,
    private = list(
      xmlElement = "EX_SpatialTemporalExtent",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "GEX"
+     )
    ),
    public = list(
      #'@field spatialExtent spatialExtent [1..*]: ISOGeographicExtent
      spatialExtent = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -61,4 +66,4 @@ ISOSpatialTemporalExtent <- R6Class("ISOSpatialTemporalExtent",
      }
      
    )                                          
-)
\ No newline at end of file
+)
