@@ -4,13 +4,15 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO unlimited integer
-#' @return Object of \code{\link{R6Class}} for modelling an ISO UnlimitedInteger
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO UnlimitedInteger
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @note Class used by geometa internal XML decoder/encoder
 #' 
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gco/1.0/gco/#element_UnlimitedInteger}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gco/1.0/gco/#element_UnlimitedInteger}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -18,7 +20,10 @@ ISOUnlimitedInteger <- R6Class("ISOUnlimitedInteger",
     inherit = ISOAbstractObject,
     private = list(
       xmlElement = "UnlimitedInteger",
-      xmlNamespacePrefix = "GCO"
+      xmlNamespacePrefix = list(
+        "19139" = "GCO",
+        "19115-3" = "GCO"
+      )
     ),
     public = list(
       #'@field value value
@@ -27,7 +32,7 @@ ISOUnlimitedInteger <- R6Class("ISOUnlimitedInteger",
       attrs = list(),
       
       #'@description Initialize object
-      #'@param xml object of class \link{XMLInternalNode-class}
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}
       #'@param value value
       initialize = function(xml = NULL, value){
         super$initialize(xml = xml)
@@ -53,4 +58,4 @@ ISOUnlimitedInteger <- R6Class("ISOUnlimitedInteger",
         }
       }
     )                        
-)
\ No newline at end of file
+)
