@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO usage
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Usage
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Usage
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Usage}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mri/1.0/mri/#element_MD_Usage} 
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,7 +18,10 @@ ISOUsage <- R6Class("ISOUsage",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_Usage",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MRI"
+    )
   ),
   public = list(
     #'@field specificUsage specificUsage
@@ -29,7 +34,7 @@ ISOUsage <- R6Class("ISOUsage",
     userContactInfo = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -64,23 +69,33 @@ ISOUsage <- R6Class("ISOUsage",
     },
     
     #'@description Adds user contact
-    #'@param contact object of class \link{ISOResponsibleParty}
+    #'@param contact object of class \link{ISOResponsibleParty} (in ISO 19139) 
+    #' or \link{ISOAbstractResponsibility} (in ISO 19115-3)
     #'@return \code{TRUE} if added, \code{FALSE} otherwise
     addUserContact = function(contact){
-      if(!is(contact,"ISOResponsibleParty")){
-        stop("The argument should be a 'ISOResponsibleParty' object")
+      classname = switch(getMetadataStandard(),
+        "19139" = "ISOResponsibleParty",
+        "19115-3" = "ISOAbstractResponsibility"
+      )
+      if(!is(contact,classname)){
+        stop("The argument should be a '",classname,"' object")
       }
       return(self$addListElement("userContactInfo", contact))
     },
     
     #'@description Deletes user contact
-    #'@param contact object of class \link{ISOResponsibleParty}
+    #'@param contact object of class \link{ISOResponsibleParty} (in ISO 19139) 
+    #' or \link{ISOAbstractResponsibility} (in ISO 19115-3)
     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
     delUserContact = function(contact){
-      if(!is(contact,"ISOResponsibleParty")){
-        stop("The argument should be a 'ISOResponsibleParty' object")
+      classname = switch(getMetadataStandard(),
+                         "19139" = "ISOResponsibleParty",
+                         "19115-3" = "ISOAbstractResponsibility"
+      )
+      if(!is(contact,classname)){
+        stop("The argument should be a '",classname,"' object")
       }
       return(self$delListElement("userContactInfo", contact))
     }
   )                                          
-)
\ No newline at end of file
+)
