@@ -466,7 +466,7 @@ test_that("encoding",{
   scriptOp$setOperationDescription("WPS Execute")
   scriptOp$setInvocationName("identifier")
   for(i in 1:3){
-    param <- ISOParameter$new()
+    param <- ISOSRVParameter$new()
     param$setName(sprintf("name%s",i), "xs:string")
     param$setDirection("in")
     param$setDescription(sprintf("description%s",i))
@@ -475,7 +475,7 @@ test_that("encoding",{
     param$setValueType("xs:string")
     scriptOp$addParameter(param)
   }
-  outParam <-ISOParameter$new()
+  outParam <-ISOSRVParameter$new()
   outParam$setName("outputname", "xs:string")
   outParam$setDirection("out")
   outParam$setDescription("outputdescription")
@@ -499,7 +499,7 @@ test_that("encoding",{
   invocationName <- "mywpsidentifier"
   wpsOp$setInvocationName(invocationName)
   for(i in 1:3){
-    param <- ISOParameter$new()
+    param <- ISOSRVParameter$new()
     param$setName(sprintf("name%s",i), "xs:string")
     param$setDirection("in")
     param$setDescription(sprintf("description%s",i))
@@ -508,7 +508,7 @@ test_that("encoding",{
     param$setValueType("xs:string")
     wpsOp$addParameter(param)
   }
-  outParam <-ISOParameter$new()
+  outParam <-ISOSRVParameter$new()
   outParam$setName("outputname", "xs:string")
   outParam$setDirection("out")
   outParam$setDescription("outputdescription")
@@ -886,7 +886,7 @@ test_that("encoding - i18n",{
   scriptOp$setOperationDescription("WPS Execute")
   scriptOp$setInvocationName("identifier")
   for(i in 1:3){
-    param <- ISOParameter$new()
+    param <- ISOSRVParameter$new()
     param$setName(sprintf("name%s",i), "xs:string")
     param$setDirection("in")
     param$setDescription(sprintf("description%s",i))
@@ -895,7 +895,7 @@ test_that("encoding - i18n",{
     param$setValueType("xs:string")
     scriptOp$addParameter(param)
   }
-  outParam <-ISOParameter$new()
+  outParam <-ISOSRVParameter$new()
   outParam$setName("outputname", "xs:string")
   outParam$setDirection("out")
   outParam$setDescription("outputdescription")
@@ -919,7 +919,7 @@ test_that("encoding - i18n",{
   invocationName <- "mywpsidentifier"
   wpsOp$setInvocationName(invocationName)
   for(i in 1:3){
-    param <- ISOParameter$new()
+    param <- ISOSRVParameter$new()
     param$setName(sprintf("name%s",i), "xs:string")
     param$setDirection("in")
     param$setDescription(sprintf("description%s",i))
@@ -928,7 +928,7 @@ test_that("encoding - i18n",{
     param$setValueType("xs:string")
     wpsOp$addParameter(param)
   }
-  outParam <-ISOParameter$new()
+  outParam <-ISOSRVParameter$new()
   outParam$setName("outputname", "xs:string")
   outParam$setDirection("out")
   outParam$setDescription("outputdescription")
